@@ -1,5 +1,5 @@
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-!   Copyright (C) 2008-2016 by Simon Prunet, Christophe Pichon et al     !
+!   Copyright (C) 2008-2017 by Simon Prunet, Christophe Pichon et al     !
 !   prunet iap.fr                                                        !
 !                                                                        !
 !   This program is free software; you can redistribute it and/or modify !
@@ -53,6 +53,9 @@ module grafic_io
      module procedure grafic_read_single, grafic_read_double
   end interface
 
+  ! TODO: When c_off_t becomes available and standard, use this
+  ! together with AC_SYS_LARGEFILE in configure.ac to get 64-bit
+  ! file offsets; change int64_t to off_t in parallel_io.c too.
   interface
      subroutine f77_parallel_read &
           (filename, fnamelen, size, offset, buffer_address)
@@ -60,7 +63,7 @@ module grafic_io
        implicit none
        character(len=128) :: filename
        integer(c_int32_t) :: fnamelen
-       integer(c_int64_t) :: size
+       integer(c_size_t) :: size ! size_t = unsigned long, cf pread(), pwrite()
        integer(c_int64_t) :: offset
        type(c_ptr), value :: buffer_address
      end subroutine f77_parallel_read
@@ -73,7 +76,7 @@ module grafic_io
        implicit none
        character(len=128) :: filename
        integer(c_int32_t) :: fnamelen
-       integer(c_int64_t) :: size
+       integer(c_size_t) :: size
        integer(c_int64_t) :: offset
        type(c_ptr), value :: buffer_address
      end subroutine f77_parallel_write
@@ -87,12 +90,16 @@ contains
   ! Beware that interior dimension is padded: nx <- 2(nx/2+1)
   ! Padded region will not be written.
   subroutine grafic_write_double(buffer,local_nz,local_z_start,ny,nx,filename,padding_in, white_in)
-
     use iso_C_binding
+#ifdef HAVE_USE_MPI_F08
+    use mpi_f08
+#endif
 
     ! Arguments
     implicit none
+#ifndef HAVE_USE_MPI_F08
     include 'mpif.h'
+#endif
     real(dp), dimension(:), intent(in) :: buffer
     integer, intent(in) :: local_nz, local_z_start, ny, nx
     character(len=128), intent(in) :: filename
@@ -109,7 +116,8 @@ contains
     integer(c_int32_t), target :: taille_tampon
 
     integer :: n2x
-    integer(i8b) :: index, index2, offset, length !, toto
+    integer(i8b) :: index, index2, offset
+    integer(c_size_t) length !, toto
     !integer :: idummy=0
     integer :: i,j,k !,myid,ierr
     logical :: padding, white
@@ -189,10 +197,15 @@ contains
 
   subroutine grafic_write_single(buffer,local_nz,local_z_start,ny,nx,filename,padding_in, white_in)
     use iso_C_binding
+#ifdef HAVE_USE_MPI_F08
+    use mpi_f08
+#endif
 
     ! Arguments
     implicit none
+#ifndef HAVE_USE_MPI_F08
     include 'mpif.h'
+#endif
     real(sp), dimension(:), intent(in) :: buffer
     integer, intent(in) :: local_nz, local_z_start, ny, nx
     character(len=128), intent(in) :: filename
@@ -210,7 +223,8 @@ contains
     integer(c_int32_t), target :: taille_tampon
 
     integer :: n2x
-    integer(i8b) :: index, index2, offset, length !, toto
+    integer(i8b) :: index, index2, offset
+    integer(c_size_t) :: length !, toto
     !integer :: idummy=0
     integer :: i,j,k !,myid,ierr
     logical :: padding, white
@@ -292,10 +306,15 @@ contains
   subroutine grafic_read_double(buffer,local_nz,local_z_start,ny,nx,filename, padding_in, white_in)
 
     use iso_C_binding
+#ifdef HAVE_USE_MPI_F08
+    use mpi_f08
+#endif
 
     ! Arguments
     implicit none
+#ifndef HAVE_USE_MPI_F08
     include 'mpif.h'
+#endif
     integer, intent(in) :: local_nz, local_z_start, ny, nx
     real(dp), dimension(local_nz*ny*2*(nx/2+1)), intent(out) :: buffer
     character(len=128), intent(in) :: filename
@@ -310,7 +329,8 @@ contains
     integer(c_int32_t), target :: taille_tampon
 
     integer :: n2x
-    integer(i8b) :: index, index2, offset, length
+    integer(i8b) :: index, index2, offset
+    integer(c_size_t) :: length
     !integer :: idummy=0
     integer :: i,j,k
     !integer :: myid,ierr
@@ -404,10 +424,15 @@ contains
 
   subroutine grafic_read_single(buffer,local_nz,local_z_start,ny,nx,filename, padding_in, white_in)
     use iso_C_binding
+#ifdef HAVE_USE_MPI_F08
+    use mpi_f08
+#endif
 
     ! Arguments
     implicit none
+#ifndef HAVE_USE_MPI_F08
     include 'mpif.h'
+#endif
     integer, intent(in) :: local_nz, local_z_start, ny, nx
     real(sp), dimension(local_nz*ny*2*(nx/2+1)), intent(out) :: buffer
     character(len=128), intent(in) :: filename
@@ -422,7 +447,8 @@ contains
     integer(c_int32_t), target :: taille_tampon
 
     integer :: n2x
-    integer(i8b) :: index, index2, offset, length
+    integer(i8b) :: index, index2, offset
+    integer(c_size_t) :: length
     !integer :: idummy=0
     integer :: i,j,k
     !integer :: myid,ierr
@@ -543,7 +569,7 @@ contains
     use iso_C_binding
     integer, intent(out) :: nx,ny,nz
 #ifdef HAVE_LIBGSL
-    integer(c_long), intent(out) :: iseed
+    integer(c_int64_t), intent(out) :: iseed
 #else
     integer, intent(out) :: iseed
 #endif
@@ -582,7 +608,7 @@ contains
     use iso_C_binding
     integer, intent(in) :: nx,ny,nz
 #ifdef HAVE_LIBGSL
-    integer(c_long), intent(in) :: iseed
+    integer(c_int64_t), intent(in) :: iseed
 #else
     integer, intent(in) :: iseed
 #endif
