@@ -1,6 +1,6 @@
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 !   mpgrafic - MPI version of N-body initial conditions grafic package   !
-!   Copyright (C) 2008-2016 by Simon Prunet, Christophe Pichon et al     !
+!   Copyright (C) 2008-2017 by Simon Prunet, Christophe Pichon et al     !
 !   prunet iap.fr                                                        !
 !                                                                        !
 !   This program is free software; you can redistribute it and/or modify !
@@ -76,7 +76,7 @@ program grafic1
   real dx,x1o,x2o,x3o,xoff,fm
   integer irand,itide,m1s,m2s,m3s !,m1off,m2off,m3off
 #ifdef HAVE_LIBGSL
-  integer (c_long) iseed
+  integer (c_int64_t) iseed
 #else
   integer iseed
 #endif
@@ -85,7 +85,7 @@ program grafic1
   integer icomp,idim,nrefine
   integer ipad, nxs, nys, nzs
 #ifdef HAVE_LIBGSL
-  integer (c_long) iseeds
+  integer (c_int64_t) iseeds
 #else
   integer iseeds
 #endif
@@ -126,7 +126,7 @@ program grafic1
         write(*,'(a)')PACKAGE_STRING
         write(*,'(a)')'Written by Simon Prunet, Christophe Pichon et al.'
         write(*,'(a)')''
-        write(*,'(a)')'Copyright (C) 2008-2016 Prunet, Pichon, Roukema.'
+        write(*,'(a)')'Copyright (C) 2008-2017 Prunet, Pichon, Roukema.'
         write(*,'(a)')'This program is free software; you may redistribute it under the terms of'
         write(*,'(a)')'the GNU General Public License version 2 or later.  This program has'
         write(*,'(a)')'absolutely no warranty.'
@@ -417,7 +417,7 @@ program grafic1
   endif
   call mpi_barrier(mpi_comm_world,ierr)
 #ifdef HAVE_LIBGSL
-  call mpi_bcast(iseed,1,mpi_long,0,mpi_comm_world,ierr)
+  call mpi_bcast(iseed,1,mpi_integer8,0,mpi_comm_world,ierr)
 #else
   call mpi_bcast(iseed,1,mpi_integer,0,mpi_comm_world,ierr)
 #endif
