@@ -1,5 +1,5 @@
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-!   Copyright (C) 2008-2016 by Simon Prunet, Christophe Pichon et al     !
+!   Copyright (C) 2008-2017 by Simon Prunet, Christophe Pichon et al     !
 !   prunet iap.fr                                                        !
 !                                                                        !
 !   This program is free software; you can redistribute it and/or modify !
@@ -35,8 +35,10 @@ subroutine mpic4(idim,irand,iseed,itide,m1s,m2s,m3s,m1off, &
   !  irand=1: use randg to generate white noise, then save in real space
   !    in filename.
   !  irand=2: read filename to get random numbers.
-  !  iseed: 9-digit integer random number seed.  Beware that rand8 does not
-  !    give the same random numbers on 32-bit and 64-bit machines!
+  !  iseed: 64-bit signed integer random number seed if GSL is available;
+  !    otherwise, 32-bit signed integer random number seed.
+  !    Beware that the pseudo-random values will differ between these
+  !    two cases!
   !  itide=0 to use full subvolume for computing f.
   !  itide=1 to set xi=0 inside subvolume so as to get outer field.
   !  itide=-1 to set xi=0 outside subvolume so as to get inner field.
@@ -73,7 +75,7 @@ subroutine mpic4(idim,irand,iseed,itide,m1s,m2s,m3s,m1off, &
   parameter (npow=30720)
   integer idim,irand,itide,m1s,m2s,m3s,m1off,m2off,m3off
 #ifdef HAVE_LIBGSL
-  integer (c_long) iseed
+  integer (c_int64_t) iseed
 #else
   integer iseed
 #endif
@@ -93,8 +95,8 @@ subroutine mpic4(idim,irand,iseed,itide,m1s,m2s,m3s,m1off, &
 #endif
   integer :: myid, nproc, ierr, i_proc
 #ifdef HAVE_LIBGSL
-  integer(c_long) :: seeds(MaxRandNumStreams,1)
-  integer(c_long) :: seed_myid ! avoid repeatedly re-calculating address
+  integer(c_int64_t) :: seeds(MaxRandNumStreams,1)
+  integer(c_int64_t) :: seed_myid ! avoid repeatedly re-calculating address
 #else
   integer :: seeds(MaxRandNumStreams,IRandNumSize)
 #endif
@@ -170,7 +172,7 @@ subroutine mpic4(idim,irand,iseed,itide,m1s,m2s,m3s,m1off, &
           write(*,'(a,i8,a,i8)')'Warning: nproc = ',nproc, &
           '> MaxRandNumStreams = ',MaxRandNumStreams
      if(myid.eq.0)call get_gsl_rng_seeds &
-             (nproc,iseed, MaxRandNumStreams, seeds(:,1))
+             (iseed, MaxRandNumStreams, seeds(:,1))
 #else
      call rans(nproc,iseed,seeds) ! Generate seeds for parallel random number generator
 #endif
@@ -182,12 +184,12 @@ subroutine mpic4(idim,irand,iseed,itide,m1s,m2s,m3s,m1off, &
         ! need to send one seed, but seeds is declared for the general case):
         do i_proc=1,nproc-1
            ! TODO: replace by broadcast or scatter?
-           call mpi_send(seeds,MaxRandNumStreams,mpi_long,i_proc, &
+           call mpi_send(seeds,MaxRandNumStreams,mpi_integer8,i_proc, &
                 0, &
                 mpi_comm_world, ierr) ! send the seeds
         enddo
      else
-        call mpi_recv(seeds,MaxRandNumStreams,mpi_long,0, &
+        call mpi_recv(seeds,MaxRandNumStreams,mpi_integer8,0, &
              0, &
              mpi_comm_world, MPI_STATUS_IGNORE, ierr)
      endif
@@ -237,7 +239,7 @@ subroutine mpic4(idim,irand,iseed,itide,m1s,m2s,m3s,m1off, &
      call mpi_bcast(i2,1,mpi_integer,0,mpi_comm_world,ierr)
      call mpi_bcast(i3,1,mpi_integer,0,mpi_comm_world,ierr)
 #ifdef HAVE_LIBGSL
-     call mpi_bcast(iseed,1,mpi_long,0,mpi_comm_world,ierr)
+     call mpi_bcast(iseed,1,mpi_integer8,0,mpi_comm_world,ierr)
 #else
      call mpi_bcast(iseed,1,mpi_integer,0,mpi_comm_world,ierr)
 #endif
