@@ -1,5 +1,5 @@
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-!   Copyright (C) 2008-2016 by Simon Prunet, Christophe Pichon et al     !
+!   Copyright (C) 2008-2017 by Simon Prunet, Christophe Pichon et al     !
 !   prunet iap.fr                                                        !
 !                                                                        !
 !   This program is free software; you can redistribute it and/or modify !
@@ -513,6 +513,10 @@ function pbar(ak,a)
 end function pbar
 !cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 subroutine pini
+#ifdef HAVE_USE_MPI_F08
+  use mpi_f08
+#endif
+
   !  Pini initializes the power spectrum.
   !parameter (pi=3.1415926535898d0)
   double precision, parameter :: pi=3.1415926535898d0
@@ -540,7 +544,9 @@ subroutine pini
   common /scaling/ a00,a10,scale
   common /extwarn/ iwarn1,iwarn2
   external dphid,dc2,dc2l,dsig8
+#ifndef HAVE_USE_MPI_F08
   include 'mpif.h'
+#endif
 
   call mpi_comm_rank(mpi_comm_world,myid,ierr)
 
@@ -556,7 +562,7 @@ subroutine pini
           &              ' (matter transfer function):'
      write(*,*) '    1 for T(k) from linger.dat'
      write(*,*) '    2 for T(k) from approx. analytical fit (BBKS)'
-     write(*,*) '    3 for T(k)=1 (scale-free)'
+     write(*,*) '    3 for T(k)=1 (scale-free)' ! TODO: See uninitialised warning below and fix.
      write(*,*) '    4 for T(k) from approx. analytical fit (E&Hu)'
      write(*,*) 'Enter case (1,2,3 or 4) now:'
      read(*,*) icase
@@ -733,6 +739,7 @@ subroutine pini
            !  Use last timestep (probably a=1) to get delta_T/T.
            if (it.eq.nt) deltat2(ik)=shearg/2.0d0
            !  Get the matter (phi) transfer function.
+           ! TODO: WARNING: grhom, grhog, grhor uninitialised  if icase .eq. 3
            grho=grhom*(om/a1+ok+ov*a1*a1)+(grhog+nnur*grhor)/(a1*a1)
            adotoa=sqrt(grho/3.0d0)
            if (initfl.gt.0) then
