@@ -1,5 +1,5 @@
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-!   Copyright (C) 2008-2016 by Simon Prunet, Christophe Pichon et al     !
+!   Copyright (C) 2008-2017 by Simon Prunet, Christophe Pichon et al     !
 !   prunet iap.fr                                                        !
 !                                                                        !
 !   This program is free software; you can redistribute it and/or modify !
@@ -45,8 +45,8 @@
 module random
   use iso_C_binding
 
-  integer(c_long),parameter :: MaxParallelism = 65536 !!! TO BE INCREASED IF NEEDED!
-  integer(c_long),parameter :: MaxRandNumStreams = MaxParallelism
+  integer(c_int32_t),parameter :: MaxParallelism = 65536 !!! TO BE INCREASED IF NEEDED!
+  integer(c_int32_t),parameter :: MaxRandNumStreams = MaxParallelism
   integer,parameter :: IRandNumSize = 4, IBinarySize = 48
   integer,parameter :: Mod4096DigitSize = 12
   !integer,parameter :: IAmountofParallelism = 128
