@@ -1,7 +1,7 @@
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 !   wrap_gsl_rng_mod - fortran wrapper for bits of GNU Scientific Library !
 !                                                                         !
-!   Copyright (C) 2016 by Boud Roukema                                    !
+!   Copyright (C) 2016-2017 by Boud Roukema                               !
 !   boud cosmo.torun.pl                                                   !
 !                                                                         !
 !   This program is free software; you can redistribute it and/or modify  !
@@ -26,16 +26,15 @@ module wrap_gsl_rng_mod
 
   interface
      subroutine get_gsl_rng_seeds &
-          (nproc, iseed, MaxRandNumStreams, seeds) &
+          (iseed, MaxRandNumStreams, seeds) &
           bind(C, name='get_gsl_rng_seeds')
        use iso_C_binding
        implicit none
        ! INPUTS
-       integer (c_int), value :: nproc
-       integer (c_long), value :: iseed
-       integer (c_long), value :: MaxRandNumStreams
+       integer (c_int64_t), value :: iseed
+       integer (c_int32_t), value :: MaxRandNumStreams
        ! OUTPUT
-       integer (c_long), dimension(MaxRandNumStreams) :: seeds
+       integer (c_int64_t), dimension(MaxRandNumStreams) :: seeds
      end subroutine get_gsl_rng_seeds
   end interface
 
@@ -45,7 +44,7 @@ module wrap_gsl_rng_mod
           bind(C, name='gauss_gsl')
        use iso_C_binding
        implicit none
-       integer (c_long), value :: Seed ! pass by value
+       integer (c_int64_t), value :: Seed ! pass by value
        real (c_double) :: RandNum ! pass by reference
        integer (c_int), value :: free_gauss_gsl ! pass by value
      end subroutine gauss_gsl
